==> ra-sdk-0.0.1-20191224.022434-2-sources.jar: com/xdja/ra/bean/EditUpdateApplyInfo.java <==
package com.xdja.ra.bean;

/**
 * @author: ggp
 * @Date: 2019/10/22 20:55
 * @Description:
 */
public class EditUpdateApplyInfo {
    /**
     * 非必须	申请原因
     */
    private String applyReason;
    /**
     * 非必须	证书主体
     */
    private String certDn;
    /**
     * 非必须	证书有效期
     */
    private Integer certValidity;
    /**
     * 非必须	待更新证书的加密证书sn
     */
    private String encSn;
    /**
     * 非必须	是否更新密钥
     */
    private Boolean isUpdateKey;
    /**
     * 非必须	待更新证书的签名证书sn
     */
    private String signSn;

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public Integer getCertValidity() {
        return certValidity;
    }

    public void setCertValidity(Integer certValidity) {
        this.certValidity = certValidity;
    }

    public String getEncSn() {
        return encSn;
    }

    public void setEncSn(String encSn) {
        this.encSn = encSn;
    }

    public Boolean getUpdateKey() {
        return isUpdateKey;
    }

    public void setUpdateKey(Boolean updateKey) {
        isUpdateKey = updateKey;
    }

    public String getSignSn() {
        return signSn;
    }

    public void setSignSn(String signSn) {
        this.signSn = signSn;
    }

    @Override
    public String toString() {
        return "EditUpdateApplyInfo{" +
                "applyReason='" + applyReason + '\'' +
                ", certDn='" + certDn + '\'' +
                ", certValidity=" + certValidity +
                ", encSn='" + encSn + '\'' +
                ", isUpdateKey=" + isUpdateKey +
                ", signSn='" + signSn + '\'' +
                '}';
    }
}

==> ra-sdk-1.0.10-20220402.121325-2-sources.jar: com/xdja/ra/bean/EditUpdateApplyInfo.java <==
package com.xdja.ra.bean;

import java.util.List;

/**
 * @author: ggp
 * @Date: 2019/10/22 20:55
 * @Description:
 */
public class EditUpdateApplyInfo {
    /**
     * 必须	申请原因
     */
    private String applyReason;
    /**
     * 必须	证书主体
     */
    private String certDn;
    /**
     * 非必须	证书有效期
     */
    private Integer certValidity;
    /**
     * 必须	是否更新密钥
     */
    private Boolean isUpdateKey;

    /**
     * 必填 是否更新有效期
     */
    private Boolean isUpdateValidity;
    /**
     * 非必须	模板自定义参数
     */
    private List<Extension> extensionList;

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public Integer getCertValidity() {
        return certValidity;
    }

    public void setCertValidity(Integer certValidity) {
        this.certValidity = certValidity;
    }

    public Boolean getUpdateKey() {
        return isUpdateKey;
    }

    public void setUpdateKey(Boolean updateKey) {
        isUpdateKey = updateKey;
    }

    public Boolean getUpdateValidity() {
        return isUpdateValidity;
    }

    public void setUpdateValidity(Boolean updateValidity) {
        isUpdateValidity = updateValidity;
    }

    public List<Extension> getExtensionList() {
        return extensionList;
    }

    public void setExtensionList(List<Extension> extensionList) {
        this.extensionList = extensionList;
    }

    @Override
    public String toString() {
        return "EditUpdateApplyInfo{" +
                "applyReason='" + applyReason + '\'' +
                ", certDn='" + certDn + '\'' +
                ", certValidity=" + certValidity +
                ", isUpdateKey=" + isUpdateKey +
                ", isUpdateValidity=" + isUpdateValidity +
                ", extensionList=" + extensionList +
                '}';
    }
}
